@@ -13,14 +13,30 @@ __PACKAGE__->mk_classdata(optional_message_params => [qw/
 __PACKAGE__->mk_classdata(required_api_params => [qw/
     /]);
 
+__PACKAGE__->mk_classdata(optional_api_params => [qw/
+	extra_params
+	/]);
+
 __PACKAGE__->mk_classdata(signature_elements => [qw/
     /]);
 
-__PACKAGE__->mk_accessors(
+__PACKAGE__->mk_classdata(all_message_params => [
     @{__PACKAGE__->required_message_params},
     @{__PACKAGE__->optional_message_params},
+	]);
+
+__PACKAGE__->mk_classdata(all_api_params => [
     @{__PACKAGE__->required_api_params},
-    qw/extra_params/
+    @{__PACKAGE__->optional_api_params},	
+	]);
+	
+__PACKAGE__->mk_classdata(all_params => [
+    @{__PACKAGE__->all_api_params},
+    @{__PACKAGE__->all_message_params},	
+	]);
+
+__PACKAGE__->mk_accessors(
+    @{__PACKAGE__->all_params},
     );
 
 =head1 NAME
